@@ -331,6 +331,21 @@ class UnQLite(object):
             for item in cursor.fetch_until(end_key, include_end_key):
                 yield item
 
+    def flush(self):
+        with self.cursor() as curs:
+            curs.first()
+            while curs.is_valid():
+                curs.delete()
+
+    def __len__(self):
+        ct = 0
+        with self.cursor() as curs:
+            curs.first()
+            while curs.is_valid():
+                ct += 1
+                curs.next()
+        return ct
+
 
 class Cursor(object):
     def __init__(self, unqlite):
